==> form-builder-vue-0.7.8.tgz: package/FormBuilder/index.ts <==
import { Ref } from 'vue';
import FormBuilder from './FormBuilder.vue';
import { CustomJSONSchema } from '../type/custom-json-schema';
import { Columns } from '../utils/columns.utils';
import { IFormWidget } from '../FormWidget';
import { UseSaveLoad } from './useSaveLoad';
import { EmitType } from '../type/emit-type';

export type FormConfig<T> = T extends number ? number : object;
export type ValidatedMeta = {
    validity: boolean;
    path: string;
    err?: { msg: string }[];
};

export type FormSchema = {
    label?: string | false;
    items?: FormSchema;
    properties?: {
        [key: string]: FormSchema;
    };
    widget: IWidget;
    validate?: boolean | ((context: IFormWidget) => boolean);
    validateFn?: (value: any, context: IFormWidget) => ValidatedMeta;
    targetPath?: string;
    view?: boolean;
    hidden?: boolean | ((context: IFormWidget) => boolean);
    required?: boolean | ((context: IFormWidget) => boolean);
    columns?: Columns;
    watch?: {
        path: PathType | ((context: IFormWidget) => PathType);
        handler: (value: any, context: IFormWidget) => void;
    }[];
    //listenTo?: string[];
    defaultValue?: any;
    props?: Record<string, any> | ((args: { form: FormBuilderContext }) => Record<string, any>);
    [key: string]: any;
};

export interface IWidget<ValueType = any, PropsType = any> {
    component: any;
    columns?: Columns;
    valueType?: ValueType;
    propsType?: PropsType;
    jsonSchemaConverter?: (formSchema: FormSchema, jsonSchema: CustomJSONSchema) => void;
}
export type FormBuilderInstance = InstanceType<typeof FormBuilder>;
export interface FormBuilderOption {
    save?: { location: string; autoSave: boolean } | false;
}

export type ConstructorToType<T extends new (...args: any[]) => any> = T extends new (...args: any[]) => infer R ? R : never;

export interface FormBuilderProps {
    schema: FormSchema;
    view?: boolean;
    disabled?: boolean;
    value?: any;
}

export type PathType = string | (string | number)[];

export type SetValueOptions = {
    disableSideEffect?: boolean;
};
export interface FormBuilderBaseContext {
    formValue: Ref<any>;
    exportValue: (options?: ExportValueOptions) => Promise<any>;
    regWidget: (path: string, widget: IFormWidget) => void;
    unRegWidget: (path: string, widget: IFormWidget) => void;
    getWidgets: (path?: PathType) => IFormWidget[];
    getValue: (path?: PathType) => any;
    setValue: (path: PathType, value: any, options?: SetValueOptions) => void;
    getSchema: (path?: PathType) => FormSchema;
    getView: () => boolean;
    validate: (option?: { scrollToInvalidWidget?: boolean }) => ValidatedMeta[];
    undoValidate: (path?: PathType) => void;
    emit: FormBuilderBaseEventEmitter;
}

export type FormBuilderContext = FormBuilderBaseContext & UseSaveLoad;
export interface ExportValueOptions {
    removeAdditional?: boolean;
}

export type FormBuilderBaseEmits = {
    'change': [value: any]; // named tuple syntax
    'update:value': [value: any];
};

export type FormBuilderBaseEventEmitter = EmitType<FormBuilderBaseEmits>;

export { FormBuilder };

==> form-builder-vue-0.7.11.tgz: package/FormBuilder/index.ts <==
import { Ref } from 'vue';
import FormBuilder from './FormBuilder.vue';
import { CustomJSONSchema } from '../type/custom-json-schema';
import { Columns } from '../utils/columns.utils';
import { IFormWidget } from '../FormWidget';
import { UseSaveLoad } from './useSaveLoad';
import { UseHistory } from './useHistory';
import { EmitType } from '../type/emit-type';

export type FormConfig<T> = T extends number ? number : object;
export type ValidatedMeta = {
    validity: boolean;
    path: string;
    err?: { msg: string }[];
};

export type FormSchema = {
    label?: string | false;
    items?: FormSchema;
    properties?: {
        [key: string]: FormSchema;
    };
    widget: IWidget;
    validate?: boolean | ((context: IFormWidget) => boolean);
    validateFn?: (value: any, context: IFormWidget) => ValidatedMeta;
    targetPath?: string;
    view?: boolean;
    hidden?: boolean | ((context: IFormWidget) => boolean);
    required?: boolean | ((context: IFormWidget) => boolean);
    columns?: Columns;
    watch?: {
        path: PathType | ((context: IFormWidget) => PathType);
        handler: (value: any, context: IFormWidget) => void;
    }[];
    //listenTo?: string[];
    defaultValue?: any;
    props?: Record<string, any> | ((args: { form: FormBuilderContext }) => Record<string, any>);
    [key: string]: any;
};

export interface IWidget<ValueType = any, PropsType = any> {
    component: any;
    columns?: Columns;
    valueType?: ValueType;
    propsType?: PropsType;
    jsonSchemaConverter?: (formSchema: FormSchema, jsonSchema: CustomJSONSchema) => void;
}
export type FormBuilderInstance = InstanceType<typeof FormBuilder>;
export interface FormBuilderOption {
    save?: { location: string; autoSave: boolean } | false;
}

export type ConstructorToType<T extends new (...args: any[]) => any> = T extends new (...args: any[]) => infer R ? R : never;

export interface FormBuilderProps {
    schema: FormSchema;
    view?: boolean;
    disabled?: boolean;
    value?: any;
    suggestion?: any;
    historyLength?: number;
}

export type PathType = string | (string | number)[];

export type SetValueOptions = {
    disableSideEffect?: boolean;
};
export interface FormBuilderBaseContext {
    formValue: Ref<any>;
    exportValue: (options?: ExportValueOptions) => Promise<any>;
    regWidget: (path: string, widget: IFormWidget) => void;
    unRegWidget: (path: string, widget: IFormWidget) => void;
    getWidgets: (path?: PathType) => IFormWidget[];
    getValue: (path?: PathType) => any;
    setValue: (path: PathType, value: any, options?: SetValueOptions) => void;
    getSchema: (path?: PathType) => FormSchema;
    getView: () => boolean;
    validate: (option?: { scrollToInvalidWidget?: boolean }) => ValidatedMeta[];
    undoValidate: (path?: PathType) => void;
    emit: FormBuilderBaseEventEmitter;
    setSuggestion: (path: PathType, value: any) => void;
    getSuggestion: (path: PathType) => any;
    rejectAllSuggestions: () => void;
    acceptAllSuggestions: (replace?: boolean) => void;
}

export type FormBuilderContext = FormBuilderBaseContext & UseSaveLoad & UseHistory;
export interface ExportValueOptions {
    removeAdditional?: boolean;
}

export type FormBuilderBaseEmits = {
    'change': [value: any]; // named tuple syntax
    'update:value': [value: any];
};

export type FormBuilderBaseEventEmitter = EmitType<FormBuilderBaseEmits>;

export { FormBuilder };
